@@ -1,4 +1,3 @@
-from __future__ import division
 from math import pi
 import random
 
@@ -14,7 +13,14 @@ water = {
 ls = {
     "molecular_weight": 14.0266,  # g/mol
     "density": 0.86,  # g/cm^3
-    "channel_weights": {"ibd": 2, "es": 8, "c12e": 1, "c12eb": 1, "c12nc": 1},
+    "channel_weights": {"ibd": 2, "es": 8, "ps": 2, "c12e": 1, "c12eb": 1, "c12nc": 1},
+}
+
+# liquid scintillator: LAB, average structure -> C_16.65H_27.3 (C6H5CnH2n+1 where n is 95% 9-12, 5% 13-14)
+lab = {
+    "molecular_weight": 227.50,  # g/mol
+    "density": 0.856,  # g/cm^3
+    "channel_weights": {"ibd": 27.3, "es": 127.2, "ps": 27.3, "c12e": 16.65, "c12eb": 16.65, "c12nc": 16.65},
 }
 
 
@@ -39,7 +45,7 @@ def wbls(x):
 # List of supported detector configurations
 supported_detectors = ["HyperK", "HyperKDR", "SuperK",
                        "WATCHMAN", "WATCHMAN-LS", "WATCHMAN-WbLS",
-                       "THEIA25", "THEIA100"]
+                       "THEIA25", "THEIA100", "SNOplusAV", "SNOplusEW"]
 
 
 class Detector(object):
@@ -90,21 +96,34 @@ class Detector(object):
             self.height = 5000
             self.radius = 5000 / 2
             self.material = wbls(0.10)  # 10% LS, 90% water
+        elif name == "SNOplusAV": # SNO+ inner AV only
+            self.shape = "sphere"
+            self.radius = 600
+            self.material = lab
+        elif name == "SNOplusEW": # SNO+ external water
+            self.shape = "hollowSphere"
+            self.innerRadius = 605
+            self.outerRadius = 900
+            self.material = water
         else:
-            raise ValueError("Unknown detector name: %s" % name)
+            raise ValueError(f"Unknown detector name: {name}")
 
         # calculate number of target molecules in detector
         if self.shape == "box":
             volume = self.x * self.y * self.z
         elif self.shape == "cylinder":
             volume = pi * self.radius ** 2 * self.height  # assumes cylindrical detector
+        elif self.shape == "sphere":
+            volume = (4 * pi * self.radius ** 3) / 3
+        elif self.shape == "hollowSphere":
+            volume = ((4 * pi * self.outerRadius ** 3) / 3) - ((4 * pi * self.innerRadius ** 3) / 3)
         else:
-            raise ValueError("Unknown detector shape: %s" % self.shape)
+            raise ValueError(f"Unknown detector shape: {self.shape}")
         number_density = self.material["density"] * 6.022e23 / self.material["molecular_weight"]
         self.n_molecules = volume * number_density
 
     def __repr__(self):
-        return "Detector('%s')" % self.name
+        return f"Detector('{self.name}')"
 
     def __setattr__(self, attr, value):
         if hasattr(self, attr):
@@ -123,6 +142,20 @@ class Detector(object):
                 if x ** 2 + y ** 2 < self.radius ** 2:
                     break
             z = random.uniform(-self.height / 2, self.height / 2)
+        elif self.shape == "sphere":
+            while True:
+                x = random.uniform(-self.radius, self.radius) 
+                y = random.uniform(-self.radius, self.radius)
+                z = random.uniform(-self.radius, self.radius)
+                if x ** 2 + y ** 2 + z ** 2 < self.radius ** 2:
+                    break
+        elif self.shape == "hollowSphere":
+            while True:
+                x = random.uniform(-self.outerRadius, self.outerRadius)
+                y = random.uniform(-self.outerRadius, self.outerRadius)
+                z = random.uniform(-self.outerRadius, self.outerRadius)
+                if (x**2 + y**2 + z**2 < self.outerRadius**2) and (x**2 + y**2 + z**2 > self.innerRadius**2):
+                    break
         else:
-            raise ValueError("Unknown detector shape: %s" % self.shape)
+            raise ValueError(f"Unknown detector shape: {self.shape}")
         return x, y, z
